@@ -2,11 +2,10 @@ from __future__ import unicode_literals
 
 import os
 
-import mopidy
-from mopidy import config, exceptions, ext
+from mopidy import config, ext
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 class RadioDeExtension(ext.Extension):
